@@ -1,5 +1,6 @@
 # for now you have to import using this line:
-from src import Core as PnP
+from src.Politics_and_Py import \
+    Core as PnP
 
 # import PnP
 
